package com.bonus.material.lease.service;

import java.util.List;
import com.bonus.material.lease.domain.LeaseAgreementRecord;

/**
 * 项目领退Service接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface ILeaseAgreementRecordService {
    /**
     * 查询项目领退
     * 
     * @param id 项目领退主键
     * @return 项目领退
     */
    public LeaseAgreementRecord selectLeaseAgreementRecordById(Long id);

    /**
     * 查询项目领退列表
     * 
     * @param leaseAgreementRecord 项目领退
     * @return 项目领退集合
     */
    public List<LeaseAgreementRecord> selectLeaseAgreementRecordList(LeaseAgreementRecord leaseAgreementRecord);

    /**
     * 新增项目领退
     * 
     * @param leaseAgreementRecord 项目领退
     * @return 结果
     */
    public int insertLeaseAgreementRecord(LeaseAgreementRecord leaseAgreementRecord);

    /**
     * 修改项目领退
     * 
     * @param leaseAgreementRecord 项目领退
     * @return 结果
     */
    public int updateLeaseAgreementRecord(LeaseAgreementRecord leaseAgreementRecord);

    /**
     * 批量删除项目领退
     * 
     * @param ids 需要删除的项目领退主键集合
     * @return 结果
     */
    public int deleteLeaseAgreementRecordByIds(Long[] ids);

    /**
     * 删除项目领退信息
     * 
     * @param id 项目领退主键
     * @return 结果
     */
    public int deleteLeaseAgreementRecordById(Long id);
}
