package com.bonus.material.lease.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.lease.domain.LeaseAgreementRecord;
import com.bonus.material.lease.service.ILeaseAgreementRecordService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 项目领退Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "项目领退接口")
@RestController
@RequestMapping("/lease_agreement_record")
public class LeaseAgreementRecordController extends BaseController {
    @Autowired
    private ILeaseAgreementRecordService leaseAgreementRecordService;

    /**
     * 查询项目领退列表
     */
    @ApiOperation(value = "查询项目领退列表")
    @RequiresPermissions("lease:record:list")
    @GetMapping("/list")
    public TableDataInfo list(LeaseAgreementRecord leaseAgreementRecord) {
        startPage();
        List<LeaseAgreementRecord> list = leaseAgreementRecordService.selectLeaseAgreementRecordList(leaseAgreementRecord);
        return getDataTable(list);
    }

    /**
     * 导出项目领退列表
     */
    @ApiOperation(value = "导出项目领退列表")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:record:export")
    @SysLog(title = "项目领退", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出项目领退")
    @PostMapping("/export")
    public void export(HttpServletResponse response, LeaseAgreementRecord leaseAgreementRecord) {
        List<LeaseAgreementRecord> list = leaseAgreementRecordService.selectLeaseAgreementRecordList(leaseAgreementRecord);
        ExcelUtil<LeaseAgreementRecord> util = new ExcelUtil<LeaseAgreementRecord>(LeaseAgreementRecord.class);
        util.exportExcel(response, list, "项目领退数据");
    }

    /**
     * 获取项目领退详细信息
     */
    @ApiOperation(value = "获取项目领退详细信息")
    @RequiresPermissions("lease:record:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(leaseAgreementRecordService.selectLeaseAgreementRecordById(id));
    }

    /**
     * 新增项目领退
     */
    @ApiOperation(value = "新增项目领退")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:record:add")
    @SysLog(title = "项目领退", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增项目领退")
    @PostMapping
    public AjaxResult add(@RequestBody LeaseAgreementRecord leaseAgreementRecord) {
        try {
            return toAjax(leaseAgreementRecordService.insertLeaseAgreementRecord(leaseAgreementRecord));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改项目领退
     */
    @ApiOperation(value = "修改项目领退")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:record:edit")
    @SysLog(title = "项目领退", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改项目领退")
    @PutMapping
    public AjaxResult edit(@RequestBody LeaseAgreementRecord leaseAgreementRecord) {
        try {
            return toAjax(leaseAgreementRecordService.updateLeaseAgreementRecord(leaseAgreementRecord));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除项目领退
     */
    @ApiOperation(value = "删除项目领退")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:record:remove")
    @SysLog(title = "项目领退", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除项目领退")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(leaseAgreementRecordService.deleteLeaseAgreementRecordByIds(ids));
    }
}
